@@ -15,7 +15,7 @@ use crate::{
 };
 
 #[derive(Debug)]
-pub struct ExceededGraphLimit {}
+pub(crate) struct ExceededGraphLimit {}
 
 /// Return the shortest route from `start` to the end vertex.
 fn shortest_vertex_path<'s, 'b>(
@@ -59,8 +59,8 @@ fn shortest_vertex_path<'s, 'b>(
 
                 if seen.len() > graph_limit {
                     info!(
-                        "Reached graph limit, arena consumed {} bytes",
-                        vertex_arena.allocated_bytes(),
+                        "Reached graph limit, arena consumed {}",
+                        humansize::format_size(vertex_arena.allocated_bytes(), humansize::BINARY),
                     );
                     return Err(ExceededGraphLimit {});
                 }
@@ -70,10 +70,10 @@ fn shortest_vertex_path<'s, 'b>(
     };
 
     info!(
-        "Saw {} vertices (a Vertex is {} bytes), arena consumed {} bytes, with {} vertices left on heap.",
+        "Saw {} vertices (a Vertex is {} bytes), arena consumed {}, with {} vertices left on heap.",
         seen.len(),
         std::mem::size_of::<Vertex>(),
-        vertex_arena.allocated_bytes(),
+        humansize::format_size(vertex_arena.allocated_bytes(), humansize::BINARY),
         heap.len(),
     );
 
@@ -186,7 +186,7 @@ fn tree_count(root: Option<&Syntax>) -> u32 {
     count
 }
 
-pub fn mark_syntax<'a>(
+pub(crate) fn mark_syntax<'a>(
     lhs_syntax: Option<&'a Syntax<'a>>,
     rhs_syntax: Option<&'a Syntax<'a>>,
     change_map: &mut ChangeMap<'a>,
