@@ -4,9 +4,10 @@ use lazy_static::lazy_static;
 use line_numbers::LinePositions;
 use regex::Regex;
 
+use crate::words::split_words;
 use crate::{
     diff::myers_diff,
-    parse::syntax::{split_words, AtomKind, MatchKind, MatchedPos, TokenKind},
+    parse::syntax::{AtomKind, MatchKind, MatchedPos, TokenKind},
 };
 
 fn split_lines_keep_newline(s: &str) -> Vec<&str> {
@@ -105,7 +106,7 @@ fn line_len_in_bytes(line: &str) -> usize {
 }
 
 // TODO: Prefer src/opposite_src nomenclature as this function is called from both sides.
-pub fn change_positions(lhs_src: &str, rhs_src: &str) -> Vec<MatchedPos> {
+pub(crate) fn change_positions(lhs_src: &str, rhs_src: &str) -> Vec<MatchedPos> {
     // TODO: If either side is "", don't split each line by words
     // pointlessly. This is common for file additions/removals.
     let lhs_lp = LinePositions::from(lhs_src);
@@ -120,9 +121,9 @@ pub fn change_positions(lhs_src: &str, rhs_src: &str) -> Vec<MatchedPos> {
             TextChangeKind::Unchanged => {
                 for (lhs_line, rhs_line) in lhs_lines.iter().zip(rhs_lines) {
                     let lhs_pos =
-                        lhs_lp.from_offsets(lhs_offset, lhs_offset + line_len_in_bytes(lhs_line));
+                        lhs_lp.from_region(lhs_offset, lhs_offset + line_len_in_bytes(lhs_line));
                     let rhs_pos =
-                        rhs_lp.from_offsets(rhs_offset, rhs_offset + line_len_in_bytes(rhs_line));
+                        rhs_lp.from_region(rhs_offset, rhs_offset + line_len_in_bytes(rhs_line));
 
                     res.push(MatchedPos {
                         kind: MatchKind::UnchangedToken {
@@ -147,25 +148,23 @@ pub fn change_positions(lhs_src: &str, rhs_src: &str) -> Vec<MatchedPos> {
                 ) {
                     match diff_res {
                         myers_diff::DiffResult::Left(lhs_word) => {
-                            if *lhs_word != "\n" {
-                                let lhs_pos =
-                                    lhs_lp.from_offsets(lhs_offset, lhs_offset + lhs_word.len());
-                                res.push(MatchedPos {
-                                    kind: MatchKind::NovelWord {
-                                        highlight: TokenKind::Atom(AtomKind::Normal),
-                                    },
-                                    pos: lhs_pos[0],
-                                });
-                            }
+                            let lhs_pos =
+                                lhs_lp.from_region(lhs_offset, lhs_offset + lhs_word.len());
+                            res.push(MatchedPos {
+                                kind: MatchKind::NovelWord {
+                                    highlight: TokenKind::Atom(AtomKind::Normal),
+                                },
+                                pos: lhs_pos[0],
+                            });
 
                             lhs_offset += lhs_word.len();
                         }
                         myers_diff::DiffResult::Both(lhs_word, rhs_word) => {
                             if *lhs_word != "\n" {
                                 let lhs_pos =
-                                    lhs_lp.from_offsets(lhs_offset, lhs_offset + lhs_word.len());
+                                    lhs_lp.from_region(lhs_offset, lhs_offset + lhs_word.len());
                                 let rhs_pos =
-                                    rhs_lp.from_offsets(rhs_offset, rhs_offset + rhs_word.len());
+                                    rhs_lp.from_region(rhs_offset, rhs_offset + rhs_word.len());
 
                                 res.push(MatchedPos {
                                     kind: MatchKind::NovelLinePart {
@@ -251,7 +250,7 @@ mod tests {
     fn test_novel_lhs_trailing_newlines() {
         let positions = change_positions("foo\n", "");
 
-        assert_eq!(positions.len(), 1);
+        assert_eq!(positions.len(), 2);
         assert!(positions[0].kind.is_novel());
     }
 
