@@ -1,11 +1,23 @@
-const C = require("tree-sitter-c/grammar")
+/**
+ * @file C++ grammar for tree-sitter
+ * @author Max Brunsfeld
+ * @license MIT
+ */
+
+/* eslint-disable arrow-parens */
+/* eslint-disable camelcase */
+/* eslint-disable-next-line spaced-comment */
+/// <reference types="tree-sitter-cli/dsl" />
+// @ts-check
+
+const C = require('tree-sitter-c/grammar');
 
 const PREC = Object.assign(C.PREC, {
   LAMBDA: 18,
   NEW: C.PREC.CALL + 1,
   STRUCTURED_BINDING: -1,
   THREE_WAY: C.PREC.RELATIONAL + 1,
-})
+});
 
 const FOLD_OPERATORS = [
   '+', '-', '*', '/', '%',
@@ -18,7 +30,8 @@ const FOLD_OPERATORS = [
   '&&', '||',
   ',',
   '.*', '->*',
-]
+  'or', 'and', 'bitor', 'xor', 'bitand', 'not_eq',
+];
 
 module.exports = grammar(C, {
   name: 'cpp',
@@ -31,6 +44,7 @@ module.exports = grammar(C, {
   conflicts: ($, original) => original.concat([
     [$.template_function, $.template_type],
     [$.template_function, $.template_type, $._expression],
+    [$.template_function, $.template_type, $._expression_not_binary],
     [$.template_function, $.template_type, $.qualified_identifier],
     [$.template_method, $.field_expression],
     [$.template_type, $.qualified_type_identifier],
@@ -38,8 +52,11 @@ module.exports = grammar(C, {
     [$.dependent_type_identifier, $.dependent_identifier],
     [$.comma_expression, $.initializer_list],
     [$._expression, $._declarator],
+    [$._expression_not_binary, $._declarator],
     [$._expression, $.structured_binding_declarator],
+    [$._expression_not_binary, $.structured_binding_declarator],
     [$._expression, $._declarator, $._type_specifier],
+    [$._expression_not_binary, $._declarator, $._type_specifier],
     [$.parameter_list, $.argument_list],
     [$._type_specifier, $.call_expression],
     [$._declaration_specifiers, $._constructor_specifiers],
@@ -71,19 +88,34 @@ module.exports = grammar(C, {
       alias($.operator_cast_declaration, $.declaration),
     ),
 
+    _block_item: ($, original) => choice(
+      original,
+      $.namespace_definition,
+      $.concept_definition,
+      $.namespace_alias_definition,
+      $.using_declaration,
+      $.alias_declaration,
+      $.static_assert_declaration,
+      $.template_declaration,
+      $.template_instantiation,
+      alias($.constructor_or_destructor_definition, $.function_definition),
+      alias($.operator_cast_definition, $.function_definition),
+      alias($.operator_cast_declaration, $.declaration),
+    ),
+
     // Types
 
     placeholder_type_specifier: $ => prec(1, seq(
       field('constraint', optional($._type_specifier)),
-      choice($.auto, alias($.decltype_auto, $.decltype))
+      choice($.auto, alias($.decltype_auto, $.decltype)),
     )),
 
-    auto: $ => 'auto',
+    auto: _ => 'auto',
     decltype_auto: $ => seq(
       'decltype',
       '(',
       $.auto,
-      ')'
+      ')',
     ),
     decltype: $ => seq(
       'decltype',
@@ -105,19 +137,18 @@ module.exports = grammar(C, {
       $.decltype,
       prec.right(choice(
         alias($.qualified_type_identifier, $.qualified_identifier),
-        $._type_identifier
-      ))
+        $._type_identifier,
+      )),
     ),
 
-    type_qualifier: ($, original) => choice(
+    type_qualifier: (_, original) => choice(
       original,
       'mutable',
-      'constexpr',
       'constinit',
       'consteval',
     ),
 
-    type_descriptor: ($, original) => prec.right(original),
+    type_descriptor: (_, original) => prec.right(original),
 
     // When used in a trailing return type, these specifiers can now occur immediately before
     // a compound statement. This introduces a shift/reduce conflict that needs to be resolved
@@ -131,45 +162,46 @@ module.exports = grammar(C, {
           optional(field('name', $._class_name)),
           optional($.virtual_specifier),
           optional($.base_class_clause),
-          field('body', $.field_declaration_list)
-        )
-      )
+          field('body', $.field_declaration_list),
+        ),
+      ),
     )),
 
     class_specifier: $ => seq(
       'class',
-      $._class_declaration
+      $._class_declaration,
     ),
 
     union_specifier: $ => seq(
       'union',
-      $._class_declaration
+      $._class_declaration,
     ),
 
     struct_specifier: $ => seq(
       'struct',
-      $._class_declaration
+      $._class_declaration,
     ),
 
     _class_name: $ => prec.right(choice(
       $._type_identifier,
       $.template_type,
-      alias($.qualified_type_identifier, $.qualified_identifier)
+      alias($.qualified_type_identifier, $.qualified_identifier),
     )),
 
     function_definition: ($, original) => ({
       ...original,
       members: original.members.map(
-        e => e.name !== 'body'
-          ? e
-          : field('body', choice(e.content, $.try_statement))) }),
+        (e) => e.name !== 'body' ?
+          e :
+          field('body', choice(e.content, $.try_statement))),
+    }),
 
-    virtual_specifier: $ => choice(
+    virtual_specifier: _ => choice(
       'final', // the only legal value here for classes
-      'override' // legal for functions in addition to final, plus permutations.
+      'override', // legal for functions in addition to final, plus permutations.
     ),
 
-    virtual: $ => choice('virtual'),
+    virtual: _ => choice('virtual'),
 
     _declaration_modifiers: ($, original) => choice(
       original,
@@ -182,8 +214,8 @@ module.exports = grammar(C, {
         'explicit',
         '(',
         $._expression,
-        ')'
-      ))
+        ')',
+      )),
     ),
 
     base_class_clause: $ => seq(
@@ -193,11 +225,11 @@ module.exports = grammar(C, {
         optional(choice(
           $.access_specifier,
           seq($.access_specifier, $.virtual),
-          seq($.virtual, $.access_specifier)
+          seq($.virtual, $.access_specifier),
         )),
         $._class_name,
-        optional('...')
-      ))
+        optional('...'),
+      )),
     ),
 
     enum_specifier: $ => prec.right(seq(
@@ -207,10 +239,10 @@ module.exports = grammar(C, {
         seq(
           field('name', $._class_name),
           optional($._enum_base_clause),
-          optional(field('body', $.enumerator_list))
+          optional(field('body', $.enumerator_list)),
         ),
-        field('body', $.enumerator_list)
-      )
+        field('body', $.enumerator_list),
+      ),
     )),
 
     _enum_base_clause: $ => prec.left(seq(
@@ -218,19 +250,19 @@ module.exports = grammar(C, {
       field('base', choice(
         alias($.qualified_type_identifier, $.qualified_identifier),
         $._type_identifier,
-        $.sized_type_specifier
-      ))
+        $.sized_type_specifier,
+      )),
     )),
 
     // The `auto` storage class is removed in C++0x in order to allow for the `auto` type.
-    storage_class_specifier: ($, original) => choice(
-      ...original.members.filter(member => member.value !== 'auto'),
+    storage_class_specifier: (_, original) => choice(
+      ...original.members.filter((member) => member.value !== 'auto'),
       'thread_local',
     ),
 
     dependent_type: $ => prec.dynamic(-1, prec.right(seq(
       'typename',
-      $._type_specifier
+      $._type_specifier,
     ))),
 
     // Declarations
@@ -246,18 +278,19 @@ module.exports = grammar(C, {
         $.template_declaration,
         $.function_definition,
         $.concept_definition,
+        $.friend_declaration,
         alias($.constructor_or_destructor_declaration, $.declaration),
         alias($.constructor_or_destructor_definition, $.function_definition),
         alias($.operator_cast_declaration, $.declaration),
         alias($.operator_cast_definition, $.function_definition),
-      )
+      ),
     ),
 
     template_instantiation: $ => seq(
       'template',
       optional($._declaration_specifiers),
       field('declarator', $._declarator),
-      ';'
+      ';',
     ),
 
     template_parameter_list: $ => seq(
@@ -269,27 +302,27 @@ module.exports = grammar(C, {
         $.variadic_parameter_declaration,
         $.variadic_type_parameter_declaration,
         $.optional_type_parameter_declaration,
-        $.template_template_parameter_declaration
+        $.template_template_parameter_declaration,
       )),
-      alias(token(prec(1, '>')), '>')
+      alias(token(prec(1, '>')), '>'),
     ),
 
     type_parameter_declaration: $ => prec(1, seq(
       choice('typename', 'class'),
-      optional($._type_identifier)
+      optional($._type_identifier),
     )),
 
     variadic_type_parameter_declaration: $ => prec(1, seq(
       choice('typename', 'class'),
       '...',
-      optional($._type_identifier)
+      optional($._type_identifier),
     )),
 
     optional_type_parameter_declaration: $ => seq(
       choice('typename', 'class'),
       optional(field('name', $._type_identifier)),
       '=',
-      field('default_type', $._type_specifier)
+      field('default_type', $._type_specifier),
     ),
 
     template_template_parameter_declaration: $ => seq(
@@ -298,8 +331,8 @@ module.exports = grammar(C, {
       choice(
         $.type_parameter_declaration,
         $.variadic_type_parameter_declaration,
-        $.optional_type_parameter_declaration
-      )
+        $.optional_type_parameter_declaration,
+      ),
     ),
 
     parameter_list: $ => seq(
@@ -308,34 +341,34 @@ module.exports = grammar(C, {
         $.parameter_declaration,
         $.optional_parameter_declaration,
         $.variadic_parameter_declaration,
-        '...'
+        '...',
       )),
-      ')'
+      ')',
     ),
 
     optional_parameter_declaration: $ => seq(
       $._declaration_specifiers,
       field('declarator', optional($._declarator)),
       '=',
-      field('default_value', $._expression)
+      field('default_value', $._expression),
     ),
 
     variadic_parameter_declaration: $ => seq(
       $._declaration_specifiers,
       field('declarator', choice(
         $.variadic_declarator,
-        alias($.variadic_reference_declarator, $.reference_declarator)
-      ))
+        alias($.variadic_reference_declarator, $.reference_declarator),
+      )),
     ),
 
     variadic_declarator: $ => seq(
       '...',
-      optional($.identifier)
+      optional($.identifier),
     ),
 
     variadic_reference_declarator: $ => seq(
       choice('&&', '&'),
-      $.variadic_declarator
+      $.variadic_declarator,
     ),
 
     init_declarator: ($, original) => choice(
@@ -344,9 +377,9 @@ module.exports = grammar(C, {
         field('declarator', $._declarator),
         field('value', choice(
           $.argument_list,
-          $.initializer_list
-        ))
-      )
+          $.initializer_list,
+        )),
+      ),
     ),
 
     operator_cast: $ => prec.right(1, seq(
@@ -357,11 +390,11 @@ module.exports = grammar(C, {
 
     // Avoid ambiguity between compound statement and initializer list in a construct like:
     //   A b {};
-    compound_statement: ($, original) => prec(-1, original),
+    compound_statement: (_, original) => prec(-1, original),
 
     field_initializer_list: $ => seq(
       ':',
-      commaSep1($.field_initializer)
+      commaSep1($.field_initializer),
     ),
 
     field_initializer: $ => prec(1, seq(
@@ -371,7 +404,7 @@ module.exports = grammar(C, {
         alias($.qualified_field_identifier, $.qualified_identifier),
       ),
       choice($.initializer_list, $.argument_list),
-      optional('...')
+      optional('...'),
     )),
 
     _field_declaration_list_item: ($, original) => choice(
@@ -387,7 +420,7 @@ module.exports = grammar(C, {
       $.alias_declaration,
       $.using_declaration,
       $.type_definition,
-      $.static_assert_declaration
+      $.static_assert_declaration,
     ),
 
     field_declaration: $ => seq(
@@ -396,9 +429,9 @@ module.exports = grammar(C, {
       optional(choice(
         $.bitfield_clause,
         field('default_value', $.initializer_list),
-        seq('=', field('default_value', choice($._expression, $.initializer_list)))
+        seq('=', field('default_value', choice($._expression, $.initializer_list))),
       )),
-      ';'
+      ';',
     ),
 
     inline_method_definition: $ => seq(
@@ -407,39 +440,39 @@ module.exports = grammar(C, {
       choice(
         field('body', choice($.compound_statement, $.try_statement)),
         $.default_method_clause,
-        $.delete_method_clause
-      )
+        $.delete_method_clause,
+      ),
     ),
 
     _constructor_specifiers: $ => choice(
       $._declaration_modifiers,
-      $.explicit_function_specifier
+      $.explicit_function_specifier,
     ),
 
     operator_cast_definition: $ => seq(
       repeat($._constructor_specifiers),
       field('declarator', choice(
         $.operator_cast,
-        alias($.qualified_operator_cast_identifier, $.qualified_identifier)
+        alias($.qualified_operator_cast_identifier, $.qualified_identifier),
       )),
-      field('body', choice($.compound_statement, $.try_statement))
+      field('body', choice($.compound_statement, $.try_statement)),
     ),
 
     operator_cast_declaration: $ => prec(1, seq(
       repeat($._constructor_specifiers),
       field('declarator', choice(
         $.operator_cast,
-        alias($.qualified_operator_cast_identifier, $.qualified_identifier)
+        alias($.qualified_operator_cast_identifier, $.qualified_identifier),
       )),
       optional(seq('=', field('default_value', $._expression))),
-      ';'
+      ';',
     )),
 
     constructor_try_statement: $ => seq(
       'try',
       optional($.field_initializer_list),
       field('body', $.compound_statement),
-      repeat1($.catch_clause)
+      repeat1($.catch_clause),
     ),
 
     constructor_or_destructor_definition: $ => seq(
@@ -448,22 +481,22 @@ module.exports = grammar(C, {
       choice(
         seq(
           optional($.field_initializer_list),
-          field('body', $.compound_statement)
+          field('body', $.compound_statement),
         ),
         alias($.constructor_try_statement, $.try_statement),
         $.default_method_clause,
-        $.delete_method_clause
-      )
+        $.delete_method_clause,
+      ),
     ),
 
     constructor_or_destructor_declaration: $ => seq(
       repeat($._constructor_specifiers),
       field('declarator', $.function_declarator),
-      ';'
+      ';',
     ),
 
-    default_method_clause: $ => seq('=', 'default', ';'),
-    delete_method_clause: $ => seq('=', 'delete', ';'),
+    default_method_clause: _ => seq('=', 'default', ';'),
+    delete_method_clause: _ => seq('=', 'delete', ';'),
 
     friend_declaration: $ => seq(
       'friend',
@@ -474,17 +507,17 @@ module.exports = grammar(C, {
           optional(choice(
             'class',
             'struct',
-            'union'
+            'union',
           )),
-          $._class_name, ';'
-        )
-      )
+          $._class_name, ';',
+        ),
+      ),
     ),
 
-    access_specifier: $ => choice(
-     'public',
-     'private',
-     'protected'
+    access_specifier: _ => choice(
+      'public',
+      'private',
+      'protected',
     ),
 
     _declarator: ($, original) => choice(
@@ -494,19 +527,19 @@ module.exports = grammar(C, {
       $.template_function,
       $.operator_name,
       $.destructor_name,
-      $.structured_binding_declarator
+      $.structured_binding_declarator,
     ),
 
     _field_declarator: ($, original) => choice(
       original,
       alias($.reference_field_declarator, $.reference_declarator),
       $.template_method,
-      $.operator_name
+      $.operator_name,
     ),
 
     _abstract_declarator: ($, original) => choice(
       original,
-      $.abstract_reference_declarator
+      $.abstract_reference_declarator,
     ),
 
     reference_declarator: $ => prec.dynamic(1, prec.right(seq(choice('&', '&&'), $._declarator))),
@@ -514,10 +547,10 @@ module.exports = grammar(C, {
     abstract_reference_declarator: $ => prec.right(seq(choice('&', '&&'), optional($._abstract_declarator))),
 
     structured_binding_declarator: $ => prec.dynamic(PREC.STRUCTURED_BINDING, seq(
-      '[', commaSep1($.identifier), ']'
+      '[', commaSep1($.identifier), ']',
     )),
 
-    ref_qualifier: $ => choice('&', '&&'),
+    ref_qualifier: _ => choice('&', '&&'),
 
     _function_declarator_seq: $ => prec.right(seq(
       field('parameters', $.parameter_list),
@@ -532,8 +565,8 @@ module.exports = grammar(C, {
       optional($.trailing_return_type),
       optional(choice(
         repeat($.virtual_specifier),
-        $.requires_clause
-      ))
+        $.requires_clause,
+      )),
     )),
 
     function_declarator: $ => prec.dynamic(1, seq(
@@ -570,22 +603,22 @@ module.exports = grammar(C, {
         '(',
         commaSep($.type_descriptor),
         ')',
-      )
+      ),
     ),
 
     template_type: $ => seq(
       field('name', $._type_identifier),
-      field('arguments', $.template_argument_list)
+      field('arguments', $.template_argument_list),
     ),
 
     template_method: $ => seq(
       field('name', $._field_identifier),
-      field('arguments', $.template_argument_list)
+      field('arguments', $.template_argument_list),
     ),
 
     template_function: $ => seq(
       field('name', $.identifier),
-      field('arguments', $.template_argument_list)
+      field('arguments', $.template_argument_list),
     ),
 
     template_argument_list: $ => seq(
@@ -593,50 +626,55 @@ module.exports = grammar(C, {
       commaSep(choice(
         prec.dynamic(3, $.type_descriptor),
         prec.dynamic(2, alias($.type_parameter_pack_expansion, $.parameter_pack_expansion)),
-        prec.dynamic(1, $._expression)
+        prec.dynamic(1, $._expression),
       )),
-      alias(token(prec(1, '>')), '>')
+      alias(token(prec(1, '>')), '>'),
     ),
 
     namespace_definition: $ => seq(
+      optional('inline'),
       'namespace',
       field('name', optional(
         choice(
-          $.identifier,
-          $.namespace_definition_name,
+          $._namespace_identifier,
+          $.nested_namespace_specifier,
         ))),
-      field('body', $.declaration_list)
+      field('body', $.declaration_list),
     ),
 
     namespace_alias_definition: $ => seq(
       'namespace',
-      field('name', $.identifier),
+      field('name', $._namespace_identifier),
       '=',
       choice(
-        $.identifier,
-        $.qualified_identifier
+        $._namespace_identifier,
+        $.nested_namespace_specifier,
       ),
-      ';'
+      ';',
     ),
 
-    namespace_definition_name: $ => seq(
-      choice(
-        $.identifier,
-        $.namespace_definition_name,
-      ),
-      '::',
+    _namespace_specifier: $ => seq(
       optional('inline'),
-      $.identifier,
+      $._namespace_identifier,
     ),
 
+    nested_namespace_specifier: $ => prec(1, seq(
+      optional($._namespace_specifier),
+      '::',
+      choice(
+        $.nested_namespace_specifier,
+        $._namespace_specifier,
+      ),
+    )),
+
     using_declaration: $ => seq(
       'using',
       optional(choice('namespace', 'enum')),
       choice(
         $.identifier,
-        $.qualified_identifier
+        $.qualified_identifier,
       ),
-      ';'
+      ';',
     ),
 
     alias_declaration: $ => seq(
@@ -645,7 +683,7 @@ module.exports = grammar(C, {
       repeat($.attribute_declaration),
       '=',
       field('type', $.type_descriptor),
-      ';'
+      ';',
     ),
 
     static_assert_declaration: $ => seq(
@@ -658,10 +696,10 @@ module.exports = grammar(C, {
           $.string_literal,
           $.raw_string_literal,
           $.concatenated_string,
-        ))
+        )),
       )),
       ')',
-      ';'
+      ';',
     ),
 
     concept_definition: $ => seq(
@@ -669,11 +707,20 @@ module.exports = grammar(C, {
       field('name', $.identifier),
       '=',
       $._expression,
-      ';'
+      ';',
     ),
 
     // Statements
 
+    _top_level_statement: ($, original) => choice(
+      original,
+      $.co_return_statement,
+      $.co_yield_statement,
+      $.for_range_loop,
+      $.try_statement,
+      $.throw_statement,
+    ),
+
     _non_case_statement: ($, original) => choice(
       original,
       $.co_return_statement,
@@ -686,13 +733,13 @@ module.exports = grammar(C, {
     switch_statement: $ => seq(
       'switch',
       field('condition', $.condition_clause),
-      field('body', $.compound_statement)
+      field('body', $.compound_statement),
     ),
 
     while_statement: $ => seq(
       'while',
       field('condition', $.condition_clause),
-      field('body', $._statement)
+      field('body', $._statement),
     ),
 
     if_statement: $ => prec.right(seq(
@@ -700,10 +747,7 @@ module.exports = grammar(C, {
       optional('constexpr'),
       field('condition', $.condition_clause),
       field('consequence', $._statement),
-      optional(seq(
-        'else',
-        field('alternative', $._statement)
-      ))
+      optional(field('alternative', $.else_clause)),
     )),
 
     for_range_loop: $ => seq(
@@ -718,7 +762,7 @@ module.exports = grammar(C, {
         $.initializer_list,
       )),
       ')',
-      field('body', $._statement)
+      field('body', $._statement),
     ),
 
     init_statement: $ => choice(
@@ -748,49 +792,49 @@ module.exports = grammar(C, {
           field('value', $._expression),
         ),
         field('value', $.initializer_list),
-      )
+      ),
     ),
 
     return_statement: ($, original) => seq(
       choice(
         original,
-        seq('return', $.initializer_list, ';')
-      )
+        seq('return', $.initializer_list, ';'),
+      ),
     ),
 
     co_return_statement: $ => seq(
       'co_return',
       optional($._expression),
-      ';'
+      ';',
     ),
 
     co_yield_statement: $ => seq(
       'co_yield',
       $._expression,
-      ';'
+      ';',
     ),
 
     throw_statement: $ => seq(
       'throw',
       optional($._expression),
-      ';'
+      ';',
     ),
 
     try_statement: $ => seq(
       'try',
       field('body', $.compound_statement),
-      repeat1($.catch_clause)
+      repeat1($.catch_clause),
     ),
 
     catch_clause: $ => seq(
       'catch',
       field('parameters', $.parameter_list),
-      field('body', $.compound_statement)
+      field('body', $.compound_statement),
     ),
 
     // Expressions
 
-    _expression: ($, original) => choice(
+    _expression_not_binary: ($, original) => choice(
       original,
       $.co_await_expression,
       $.requires_expression,
@@ -801,11 +845,10 @@ module.exports = grammar(C, {
       $.delete_expression,
       $.lambda_expression,
       $.parameter_pack_expansion,
-      $.nullptr,
       $.this,
       $.raw_string_literal,
       $.user_defined_literal,
-      $.fold_expression
+      $.fold_expression,
     ),
 
     raw_string_literal: $ => seq(
@@ -830,18 +873,18 @@ module.exports = grammar(C, {
       field('argument', $._expression),
       '[',
       field('index', choice($._expression, $.initializer_list)),
-      ']'
+      ']',
     )),
 
 
     call_expression: ($, original) => choice(original, seq(
       field('function', $.primitive_type),
-      field('arguments', $.argument_list)
+      field('arguments', $.argument_list),
     )),
 
     co_await_expression: $ => prec.left(PREC.UNARY, seq(
       field('operator', 'co_await'),
-      field('argument', $._expression)
+      field('argument', $._expression),
     )),
 
     new_expression: $ => prec.right(PREC.NEW, seq(
@@ -852,22 +895,22 @@ module.exports = grammar(C, {
       field('declarator', optional($.new_declarator)),
       field('arguments', optional(choice(
         $.argument_list,
-        $.initializer_list
-      )))
+        $.initializer_list,
+      ))),
     )),
 
     new_declarator: $ => prec.right(seq(
       '[',
       field('length', $._expression),
       ']',
-      optional($.new_declarator)
+      optional($.new_declarator),
     )),
 
     delete_expression: $ => seq(
       optional('::'),
       'delete',
       optional(seq('[', ']')),
-      $._expression
+      $._expression,
     ),
 
     field_expression: ($, original) => choice(
@@ -875,14 +918,14 @@ module.exports = grammar(C, {
       seq(
         prec(PREC.FIELD, seq(
           field('argument', $._expression),
-          choice('.', '->')
+          choice('.', '->'),
         )),
         field('field', choice(
           $.destructor_name,
           $.template_method,
-          alias($.dependent_field_identifier, $.dependent_name)
-        ))
-      )
+          alias($.dependent_field_identifier, $.dependent_name),
+        )),
+      ),
     ),
 
     type_requirement: $ => seq('typename', $._class_name),
@@ -891,13 +934,13 @@ module.exports = grammar(C, {
       '{', $._expression, '}',
       optional('noexcept'),
       optional($.trailing_return_type),
-      ';'
+      ';',
     ),
 
     _requirement: $ => choice(
       alias($.expression_statement, $.simple_requirement),
       $.type_requirement,
-      $.compound_requirement
+      $.compound_requirement,
     ),
 
     requirement_seq: $ => seq('{', repeat($._requirement), '}'),
@@ -905,13 +948,13 @@ module.exports = grammar(C, {
     constraint_conjunction: $ => prec.left(PREC.LOGICAL_AND, seq(
       field('left', $._requirement_clause_constraint),
       field('operator', choice('&&', 'and')),
-      field('right', $._requirement_clause_constraint))
+      field('right', $._requirement_clause_constraint)),
     ),
 
     constraint_disjunction: $ => prec.left(PREC.LOGICAL_OR, seq(
       field('left', $._requirement_clause_constraint),
       field('operator', choice('||', 'or')),
-      field('right', $._requirement_clause_constraint))
+      field('right', $._requirement_clause_constraint)),
     ),
 
     _requirement_clause_constraint: $ => choice(
@@ -933,7 +976,7 @@ module.exports = grammar(C, {
 
     requires_clause: $ => seq(
       'requires',
-      field('constraint', $._requirement_clause_constraint)
+      field('constraint', $._requirement_clause_constraint),
     ),
 
     requires_parameter_list: $ => seq(
@@ -943,13 +986,13 @@ module.exports = grammar(C, {
         $.optional_parameter_declaration,
         $.variadic_parameter_declaration,
       )),
-      ')'
+      ')',
     ),
 
     requires_expression: $ => seq(
       'requires',
       field('parameters', optional(alias($.requires_parameter_list, $.parameter_list))),
-      field('requirements', $.requirement_seq)
+      field('requirements', $.requirement_seq),
     ),
 
     lambda_expression: $ => seq(
@@ -959,7 +1002,7 @@ module.exports = grammar(C, {
         optional(field('constraint', $.requires_clause)),
       )),
       optional(field('declarator', $.abstract_function_declarator)),
-      field('body', $.compound_statement)
+      field('body', $.compound_statement),
     ),
 
     lambda_capture_specifier: $ => prec(PREC.LAMBDA, seq(
@@ -969,31 +1012,31 @@ module.exports = grammar(C, {
         commaSep($._expression),
         seq(
           $.lambda_default_capture,
-          ',', commaSep1($._expression)
-        )
+          ',', commaSep1($._expression),
+        ),
       ),
-      ']'
+      ']',
     )),
 
-    lambda_default_capture: $ => choice('=', '&'),
+    lambda_default_capture: _ => choice('=', '&'),
 
-    _fold_operator: $ => choice(...FOLD_OPERATORS),
-    _binary_fold_operator: $ => choice(...FOLD_OPERATORS.map(operator => seq(field('operator', operator), '...', operator))),
+    _fold_operator: _ => choice(...FOLD_OPERATORS),
+    _binary_fold_operator: _ => choice(...FOLD_OPERATORS.map((operator) => seq(field('operator', operator), '...', operator))),
 
     _unary_left_fold: $ => seq(
       field('left', '...'),
       field('operator', $._fold_operator),
-      field('right', $._expression)
+      field('right', $._expression),
     ),
     _unary_right_fold: $ => seq(
       field('left', $._expression),
       field('operator', $._fold_operator),
-      field('right', '...')
+      field('right', '...'),
     ),
     _binary_fold: $ => seq(
       field('left', $._expression),
       $._binary_fold_operator,
-      field('right', $._expression)
+      field('right', $._expression),
     ),
 
     fold_expression: $ => seq(
@@ -1001,19 +1044,19 @@ module.exports = grammar(C, {
       choice(
         $._unary_right_fold,
         $._unary_left_fold,
-        $._binary_fold
+        $._binary_fold,
       ),
-      ')'
+      ')',
     ),
 
     parameter_pack_expansion: $ => prec(-1, seq(
       field('pattern', $._expression),
-      '...'
+      '...',
     )),
 
     type_parameter_pack_expansion: $ => seq(
       field('pattern', $.type_descriptor),
-      '...'
+      '...',
     ),
 
     sizeof_expression: ($, original) => prec.right(PREC.SIZEOF, choice(
@@ -1022,7 +1065,7 @@ module.exports = grammar(C, {
         'sizeof', '...',
         '(',
         field('value', $.identifier),
-        ')'
+        ')',
       ),
     )),
 
@@ -1030,18 +1073,18 @@ module.exports = grammar(C, {
       original,
       prec.left(PREC.UNARY, seq(
         field('operator', choice('not', 'compl')),
-        field('argument', $._expression)
-      ))
+        field('argument', $._expression),
+      )),
     ),
 
     binary_expression: ($, original) => {
       const table = [
         ['<=>', PREC.THREE_WAY],
-        ['or',  PREC.LOGICAL_OR],
+        ['or', PREC.LOGICAL_OR],
         ['and', PREC.LOGICAL_AND],
         ['bitor', PREC.INCLUSIVE_OR],
         ['xor', PREC.EXCLUSIVE_OR],
-        ['bitand',  PREC.BITWISE_AND],
+        ['bitand', PREC.BITWISE_AND],
         ['not_eq', PREC.EQUAL],
       ];
 
@@ -1050,16 +1093,17 @@ module.exports = grammar(C, {
         ...table.map(([operator, precedence]) => {
           return prec.left(precedence, seq(
             field('left', $._expression),
+            // @ts-ignore
             field('operator', operator),
-            field('right', $._expression)
-          ))
+            field('right', $._expression),
+          ));
         }));
     },
 
     argument_list: $ => seq(
       '(',
       commaSep(choice($._expression, $.initializer_list)),
-      ')'
+      ')',
     ),
 
     destructor_name: $ => prec(1, seq('~', $.identifier)),
@@ -1068,20 +1112,20 @@ module.exports = grammar(C, {
       original,
       seq(
         field('type', $._class_name),
-        field('value', $.initializer_list)
-      )
+        field('value', $.initializer_list),
+      ),
     ),
 
     dependent_identifier: $ => seq('template', $.template_function),
     dependent_field_identifier: $ => seq('template', $.template_method),
     dependent_type_identifier: $ => seq('template', $.template_type),
 
-    _scope_resolution: $=> prec(1, seq(
+    _scope_resolution: $ => prec(1, seq(
       field('scope', optional(choice(
         $._namespace_identifier,
         $.template_type,
         $.decltype,
-        alias($.dependent_type_identifier, $.dependent_name)
+        alias($.dependent_type_identifier, $.dependent_name),
       ))),
       '::',
     )),
@@ -1092,8 +1136,8 @@ module.exports = grammar(C, {
         alias($.dependent_field_identifier, $.dependent_name),
         alias($.qualified_field_identifier, $.qualified_identifier),
         $.template_method,
-        $._field_identifier
-      ))
+        $._field_identifier,
+      )),
     ),
 
     qualified_identifier: $ => seq(
@@ -1104,7 +1148,7 @@ module.exports = grammar(C, {
         $.template_function,
         $.identifier,
         $.operator_name,
-        $.destructor_name
+        $.destructor_name,
       )),
     ),
 
@@ -1114,7 +1158,7 @@ module.exports = grammar(C, {
         alias($.dependent_type_identifier, $.dependent_name),
         alias($.qualified_type_identifier, $.qualified_identifier),
         $.template_type,
-        $._type_identifier
+        $._type_identifier,
       )),
     ),
 
@@ -1122,8 +1166,8 @@ module.exports = grammar(C, {
       $._scope_resolution,
       field('name', choice(
         alias($.qualified_operator_cast_identifier, $.qualified_identifier),
-        $.operator_cast
-      ))
+        $.operator_cast,
+      )),
     ),
 
     _assignment_left_expression: ($, original) => choice(
@@ -1138,10 +1182,10 @@ module.exports = grammar(C, {
         field('operator', choice(
           'and_eq',
           'or_eq',
-          'xor_eq'
+          'xor_eq',
         )),
-        field('right', $._expression)
-      ))
+        field('right', $._expression),
+      )),
     ),
 
     operator_name: $ => prec(1, seq(
@@ -1165,19 +1209,18 @@ module.exports = grammar(C, {
         'not', 'xor_eq', 'and_eq', 'or_eq', 'not_eq',
         'and', 'or',
         seq(choice('new', 'delete'), optional('[]')),
-        seq('""', $.identifier)
-      )
+        seq('""', $.identifier),
+      ),
     )),
 
-    this: $ => 'this',
-    nullptr: $ => 'nullptr',
+    this: _ => 'this',
 
     concatenated_string: $ => seq(
       choice($.raw_string_literal, $.string_literal),
-      repeat1(choice($.raw_string_literal, $.string_literal))
+      repeat1(choice($.raw_string_literal, $.string_literal)),
     ),
 
-    literal_suffix: $ => token.immediate(/[a-zA-Z_]\w*/),
+    literal_suffix: _ => token.immediate(/[a-zA-Z_]\w*/),
 
     user_defined_literal: $ => seq(
       choice(
@@ -1185,19 +1228,35 @@ module.exports = grammar(C, {
         $.char_literal,
         $.string_literal,
         $.raw_string_literal,
-        $.concatenated_string
+        $.concatenated_string,
       ),
-      $.literal_suffix
+      $.literal_suffix,
     ),
 
-    _namespace_identifier: $ => alias($.identifier, $.namespace_identifier)
-  }
+    _namespace_identifier: $ => alias($.identifier, $.namespace_identifier),
+  },
 });
 
+/**
+ * Creates a rule to optionally match one or more of the rules separated by a comma
+ *
+ * @param {Rule} rule
+ *
+ * @return {ChoiceRule}
+ *
+ */
 function commaSep(rule) {
   return optional(commaSep1(rule));
 }
 
+/**
+ * Creates a rule to match one or more of the rules separated by a comma
+ *
+ * @param {Rule} rule
+ *
+ * @return {SeqRule}
+ *
+ */
 function commaSep1(rule) {
   return seq(rule, repeat(seq(',', rule)));
 }
